==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/member/MemberSyncBbxNewCustomerReqBean.java <==
package global.hh.openapi.sdk.api.bean.member;


/**
 * @description: cust-consume-records-controller
 * @author: 777771
 * @date: 2019-31-17 10:31:31
 */
public class MemberSyncBbxNewCustomerReqBean {
    /**
     * 宝宝生日。时间戳(毫秒)
     */
    private Long birthday;

    /**
     * 会员编号（不用传）
     */
    private Long customerId;

    /**
     * 性别
     */
    private Long gender;

    /**
     * 宝宝名称
     */
    private String kidName;

    /**
     * 手机号
     */
    private String mobile;

    /**
     * 会员姓名
     */
    private String name;

    /**
     * 品牌
     */
    private String outerBrand;

    public MemberSyncBbxNewCustomerReqBean(){
    }

    public MemberSyncBbxNewCustomerReqBean(Long birthday,Long customerId,Long gender,String kidName,String mobile,String name,String outerBrand){
        this.birthday=birthday;
        this.customerId=customerId;
        this.gender=gender;
        this.kidName=kidName;
        this.mobile=mobile;
        this.name=name;
        this.outerBrand=outerBrand;
    }

    private Long getBirthday() {
        return birthday;
    }

    private void setBirthday(Long birthday) {
        this.birthday = birthday;
    }
    private Long getCustomerId() {
        return customerId;
    }

    private void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    private Long getGender() {
        return gender;
    }

    private void setGender(Long gender) {
        this.gender = gender;
    }
    private String getKidName() {
        return kidName;
    }

    private void setKidName(String kidName) {
        this.kidName = kidName;
    }
    private String getMobile() {
        return mobile;
    }

    private void setMobile(String mobile) {
        this.mobile = mobile;
    }
    private String getName() {
        return name;
    }

    private void setName(String name) {
        this.name = name;
    }
    private String getOuterBrand() {
        return outerBrand;
    }

    private void setOuterBrand(String outerBrand) {
        this.outerBrand = outerBrand;
    }
}

==> biostime-openapi-sdk-1.5.8.8-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/member/MemberSyncBbxNewCustomerReqBean.java <==
package global.hh.openapi.sdk.api.bean.member;


/**
 * @description: （废弃）同步会员：根据手机号码判断是否为新客，且同步会员信息
 * @author: 12360
 * @date: 2019-15-04 16:15:52
 */
public class MemberSyncBbxNewCustomerReqBean {
    /**
     * 宝宝生日。时间戳(毫秒)
     */
    private Long birthday;

    /**
     * 会员编号（不用传）
     */
    private Long customerId;

    /**
     * 性别
     */
    private Long gender;

    /**
     * 宝宝名称
     */
    private String kidName;

    /**
     * 手机号
     */
    private String mobile;

    /**
     * 会员姓名
     */
    private String name;

    /**
     * 品牌
     */
    private String outerBrand;

    public MemberSyncBbxNewCustomerReqBean(){
    }

    public MemberSyncBbxNewCustomerReqBean(Long birthday,Long customerId,Long gender,String kidName,String mobile,String name,String outerBrand){
        this.birthday=birthday;
        this.customerId=customerId;
        this.gender=gender;
        this.kidName=kidName;
        this.mobile=mobile;
        this.name=name;
        this.outerBrand=outerBrand;
    }

    public Long getBirthday() {
        return birthday;
    }

    public void setBirthday(Long birthday) {
        this.birthday = birthday;
    }
    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public Long getGender() {
        return gender;
    }

    public void setGender(Long gender) {
        this.gender = gender;
    }
    public String getKidName() {
        return kidName;
    }

    public void setKidName(String kidName) {
        this.kidName = kidName;
    }
    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getOuterBrand() {
        return outerBrand;
    }

    public void setOuterBrand(String outerBrand) {
        this.outerBrand = outerBrand;
    }
}
